<?php

namespace HaoZiTeam\WPChatGPT\Service;

use RAT;

defined( 'ABSPATH' ) || exit;

class Setting {

	private string $prefix = 'wp-chatgpt';

	public function __construct() {
		add_filter( 'rat_welcome_page', '__return_false' );
		self::admin_init();
	}

	public function admin_init(): void {
		RAT::createOptions( $this->prefix, [
			'framework_title' => 'AI 聊天',
			'menu_title'      => 'AI 聊天',
			'menu_slug'       => 'wp-chatgpt',
			'menu_type'       => 'submenu',
			'menu_parent'     => 'options-general.php',
			'show_bar_menu'   => false,
			'show_sub_menu'   => false,
			'show_search'     => false,
			'footer_text'     => 'AI聊天 专业版已开售，支持更多功能。<a href="https://hzbk.net/archives/61055.html" target="_blank">点击查看详情</a>',
			'theme'           => 'light',
		] );

		RAT::createSection( $this->prefix, [
			'title'  => 'AI 聊天 设置',
			'fields' => [
				[
					'type'    => 'content',
					'content' => 'AI聊天 专业版已开售，支持更多功能。<a href="https://hzbk.net/archives/61055.html" target="_blank">点击查看详情</a>',
				],
				[
					'type'    => 'content',
					'content' => '请新建页面并插入<code>[wp-chatgpt]</code>简码即可使用。若显示错位，你可以像这样添加class<code>[wp-chatgpt class="wp-chatgpt-frontend your-class"]</code>进行调整',
				],
				[
					'id'       => 'openai-api-server',
					'type'     => 'text',
					'title'    => 'API 服务器',
					'subtitle' => 'AI API 接口地址',
					'desc'     => '不填则使用默认 API 服务器地址，如需使用其他 API 服务器，请填写完整的 API 地址。<br>默认：<code>https://api.openai.com/</code>',
				],
				[
					'id'         => 'chatgpt-system-prompt',
					'type'       => 'textarea',
					'default'    => '你是 ChatGPT，一个由 OpenAI 训练的大型语言模型，模型是 GPT-3.5，当前时间是 {datetime}。尽可能简洁地回答。',
					'title'      => 'AI 默认设定',
					'desc'       => '设定词，将作为系统词伴随整个会话。可用变量：<code>{datetime}</code>（当前日期和时间）',
				],
				[
					'id'     => 'sensitive-words',
					'type'   => 'repeater',
					'title'  => '敏感词过滤',
					'desc'   => '输入敏感词，当检测到输出/输入中包含敏感词时，将会自动过滤',
					'fields' => [
						[
							'id'    => 'sensitive-word',
							'type'  => 'text',
							'title' => '敏感词',
						],
					],
				],
				[
					'id'      => 'conversation-trash',
					'type'    => 'switcher',
					'default' => false,
					'title'   => '对话回收站',
					'label'   => '开启后，用户删除的对话将会被移到回收站中，而不是直接删除。',
				],
				[
					'id'      => 'message-trash',
					'type'    => 'switcher',
					'default' => false,
					'title'   => '消息回收站',
					'label'   => '开启后，用户删除的消息将会被移到回收站中，而不是直接删除。',
				]
			],
		] );

		RAT::createSection( $this->prefix, [
			'title'  => 'AI 账号',
			'fields' => [
				[
					'type'    => 'content',
					'content' => 'AI聊天 专业版已开售，支持更多功能。<a href="https://hzbk.net/archives/61055.html" target="_blank">点击查看详情</a>',
				],
				[
					'type'    => 'content',
					'content' => '可以设置多个账号，每次请求将会自动随机选择，以降低账号被限制的风险。',
				],
				[
					'id'                     => 'openai-accounts',
					'type'                   => 'group',
					'title'                  => '账号列表',
					'subtitle'               => '添加 AI 账号',
					'desc'                   => '添加多个 AI 账号，将会自动进行轮询，以降低账号被限制的风险',
					'button_title'           => '添加账号',
					'accordion_title_number' => true,
					'fields'                 => [
						[
							'id'    => 'account-note',
							'type'  => 'text',
							'title' => '账号备注',
							'desc'  => '账号备注，用于区分账号',
						],
						[
							'id'         => 'account-secret-key',
							'type'       => 'text',
							'title'      => 'Secret Key',
							'subtitle'   => 'AI 账号的 Secret Key',
							'desc'       => '登录后从 <a href="https://platform.openai.com/account/api-keys" target="_blank">https://platform.openai.com/account/api-keys</a> 获取',
						],
					],
				],
			],
		] );
	}
}
